#ifdef KISSME_LINUX_KERNEL

#ifdef USE_PRINTK
#define eprintf(format, args...) printk(format, ## args)
#else
#define eprintf(format, args...) ;
#endif


#else
#ifdef KISSME_RJK_KERNEL
#define eprintf(format, args...) kinterface->kprintf(format, ## args);

#else

#ifdef USE_PRINTK
#include <stdio.h>

#define eprintf(format, args...) printf(format, ## args)
#else
//not sure about this line
//maybe just #define eprintf(format, args ...)
#define eprintf(format, args...) ;
#endif

#endif
#endif
